@@ -3,6 +3,7 @@ import os
 
 # Packages
 import flask
+import user_agents
 
 # Local
 from canonicalwebteam.search.models import get_search_results
@@ -60,6 +61,19 @@ def build_search_view(
         results = None
 
         if query:
+            # Block weird characters
+            illegal_characters = ("【", "】")
+
+            if any(char in query for char in illegal_characters):
+                flask.abort(403, "Search query contains an illegal character")
+
+            # Block if a search bot
+            agent = user_agents.parse(str(flask.request.user_agent))
+            if agent.is_bot:
+                flask.abort(
+                    403, "Search engine crawlers can't perform searches"
+                )
+
             results = get_search_results(
                 session=session,
                 api_key=search_api_key,
@@ -71,13 +85,26 @@ def build_search_view(
                 num=num,
             )
 
-        return flask.render_template(
-            template_path,
-            query=query,
-            start=start,
-            num=num,
-            results=results,
-            siteSearch=site_search,
-        )
+            return (
+                flask.render_template(
+                    template_path,
+                    query=query,
+                    start=start,
+                    num=num,
+                    results=results,
+                    siteSearch=site_search,
+                ),
+                {"X-Robots-Tag": "noindex"},
+            )
+
+        else:
+            return flask.render_template(
+                template_path,
+                query=query,
+                start=start,
+                num=num,
+                results=results,
+                siteSearch=site_search,
+            )
 
     return search_view
